#pragma once

// Stores a 80x30 text character buffer.
extern char __attribute__((far,noload)) vdc_text_buffer[80 * 30];

// Defines the current text viewport.
extern struct vdc_rectangle_t vdc_text_viewport;

// Stores the current text cursor position.
extern struct vdc_point_2d_t vdc_text_cursor_position;

// Stores the text foreground colour.
extern unsigned int vdc_text_foreground_colour;

// Stores the text background colour.
extern unsigned int vdc_text_background_colour;

// Resets the font size to the small font, resets the text viewport, sets the background colour to black, the foreground colour to white and clears the screen.
void vdc_text_reset(void);

// Clears the text viewport.
void vdc_text_clear(void);

// Resets the text viewport to fill the screen.
void vdc_text_reset_viewport(void);

// Set the text viewport. The viewport is clipped to the screen and if the cursor is no longer inside the viewport it is moved to the top-left of the new viewport.
void vdc_text_set_viewport(struct vdc_rectangle_t rect);

// Puts a character on the display at the current cursor position.
void vdc_text_put_map(char c);

// Puts a character on the display at the current cursor position and advances the cursor.
void vdc_text_put_char(char c);

// Moves the text cursor right a column. If it moves past the right edge of the viewport the cursor returns to the left edge of the viewport and down a row.
void vdc_text_move_cursor_right(void);

// Moves the text cursor down a row. If it moves past the bottom edge of the viewport the cursor returns to the bottom edge of the viewport and the viewport scrolls up one row.
void vdc_text_move_cursor_down(void);

// Moves the text cursor left a column. If it moves past the left edge of the viewport the cursor returns to the right edge of the viewport and up a row.
void vdc_text_move_cursor_left(void);

// Moves the cursor up a row. If it moves past the top edge of the viewport the cursor returns to the top edge and the viewport scrolls down one row.
void vdc_text_move_cursor_up(void);

// Scrolls the viewport up one row.
void vdc_text_scroll_up(void);

// Scrolls the viewport down one row.
void vdc_text_scroll_down(void);
